print.rfsrc: Print Summary Output of a RF-SRC Analysis

View source: R/print.rfsrc.R

print.rfsrcR Documentation

Print Summary Output of a RF-SRC Analysis

Description

Print summary output from a RF-SRC analysis. This is the default print method for the package.

Usage

## S3 method for class 'rfsrc'
print(x, outcome.target = NULL, ...,
                          quantreg.tau = NULL)

Arguments

x

An object of class (rfsrc, grow), or (rfsrc, predict).

outcome.target

Character value for multivariate families specifying the target outcome to be used. The default is to use the first coordinate from the continuous outcomes (otherwise if none, the first coordinate from the categorical outcomes).

...

Further arguments passed to or from other methods.

quantreg.tau

Optional numeric vector of finite levels strictly between zero and one for the printed pinball losses of a quantile regression object. Supply this argument by name. When NULL, uses the session option quantreg.tau, then the former rfsrc.pinball.taus option for compatibility, then c(0.1, 0.5, 0.9). Explicit levels apply to this print call only and do not change the fitted object or session options. See quantreg for details.

Author(s)

Hemant Ishwaran and Udaya B. Kogalur

References

Ishwaran H. and Kogalur U.B. (2007). Random survival forests for R, Rnews, 7/2:25-31.

Examples

  iris.obj <- rfsrc(Species ~., data = iris, ntree=10)
  print(iris.obj)

randomForestSRC documentation built on Sept. 16, 2026, 5:06 p.m.